Tutorials — Crappy 1.5.3 documentation

# Tutorials

- How to generate a signal with CRAPPY ?
  - Choose a signal
    - 1. Constant signals
    - 2. Ramp signals
    - 3. Sine signals
    - 4. Cyclic ramp signals
    - 5. Custom signals
  - Generate a signal
  - Plot a signal
  - Code Example
  - Another example
- How to use C++ designed hardware drivers with Crappy ?
  - How to bind C/C++ with Crappy?
  - First example
    - The C++ code (hello.cpp)
    - Adding the binding to Crappy
  - A more oriented object module